@@ -1,5 +1,7 @@
 '''initialize'''
+from .ku6 import Ku6
 from .ted import Ted
+from .sohu import Sohu
 from .cntv import CNTV
 from .mgtv import MGTV
 from .migu import Migu
@@ -8,7 +10,11 @@ from .acfun import AcFun
 from .zhihu import Zhihu
 from .xigua import Xigua
 from .iqiyi import Iqiyi
+from .weibo import Weibo
 from .douyin import Douyin
 from .haokan import Haokan
+from .kuaishou import Kuaishou
 from .bilibili import Bilibili
+from .yinyuetai import Yinyuetai
+from .baidutieba import BaiduTieba
 from .pipigaoxiao import Pipigaoxiao
\ No newline at end of file
