@@ -8,7 +8,7 @@ Author:
 '''
 import time
 from .base import Base
-from ..utils.misc import *
+from ..utils import filterBadCharacter
 
 
 '''咪咕视频下载器类'''
@@ -47,7 +47,7 @@ class Migu(Base):
             'source': self.source,
             'download_url': download_url,
             'savedir': self.config['savedir'],
-            'savename': '_'.join([self.source, filterBadCharacter(title)]),
+            'savename': filterBadCharacter(title),
             'ext': 'mp4',
         }
         return [videoinfo]
